@@ -27,7 +27,7 @@ class ElfAddrObj(ELFFile):
     DW_AT_TYPEDEF = 'DW_TAG_typedef'
     DW_AT_NAME = 'DW_AT_name'
     DW_AT_BASE_TYPE = 'DW_TAG_base_type'
-    version = '0.0.3'
+    version = '0.0.5'
 
     def __init__(self, elf_file):
         self.struct_dict = objdict()
@@ -50,7 +50,10 @@ class ElfAddrObj(ELFFile):
         self.elffile = ELFFile(self._elf_file_handler)
         self.dwarfinfo = self.elffile.get_dwarf_info()
         self.section_offset = self.dwarfinfo.debug_info_sec.global_offset
-        fileConfig('logging.conf')
+        try:
+            fileConfig('logging.conf')
+        except KeyError:
+            print("Logging configuration file not found.")
         self._logger = logging.getLogger()
         self._parse_symbol_table()
         self._parse_debug_info()
@@ -168,6 +171,7 @@ class ElfAddrObj(ELFFile):
             attrs = self._attr_to_dict(next_die)
             self.offset_dict[die.offset][attrs.DW_AT_name] = attrs
             next_die = next(iter_dies)
+        self._process_die(next_die, iter_dies)
 
     def _process_unneeded(self, die, iter_dies):
         while(1):
@@ -206,8 +210,10 @@ class ElfAddrObj(ELFFile):
         if self.DW_AT_NAME in attrs:
             at_name = attrs.DW_AT_name
         else:
-            # Todo will be handled later
-            print(attrs)
+            at_name = die.offset
+            self._logger.warning(
+                "None named variable found with offset:{0}".format(die.offset))
+            attrs.DW_AT_name = die.offset
         attrs.tag = die.tag
         self.variables_dict[at_name] = attrs
 
@@ -235,7 +241,7 @@ class ElfAddrObj(ELFFile):
                     member_name = i.DW_AT_name
                     self.struct_dict[struct_name][member_name] = i
             next_die = next(iter_dies)
-
+        self._process_die(next_die, iter_dies)
 
     def _process_base_type(self, die):
         attrs = self._attr_to_dict(die)
@@ -430,11 +436,14 @@ class ElfAddrObj(ELFFile):
 
     def get_enum_info(self, name):
         enum_type = None
+        res = None
         if name in self.enum_dict:
             enum_type = self.offset_dict[self.enum_dict[name].offset]
         elif name in self.typedef_dict:
             enum_type = self.offset_dict[self.typedef_dict[name].DW_AT_type]
             while enum_type.tag == self.DW_AT_TYPEDEF:
                 enum_type = self.offset_dict[enum_type.DW_AT_type]
-        return {i: enum_type[i].DW_AT_const_value for i in enum_type if type(enum_type[i]) == objdict}
+        if enum_type:
+            res = {i: enum_type[i].DW_AT_const_value for i in enum_type if type(enum_type[i]) == objdict}
+        return res
 
